@@ -720,6 +720,8 @@ class Sf:
         
         return {'profiles_with_apex_page_access': profiles_with_apex_page_access, 'permission_sets_with_apex_page_access': permission_sets_with_apex_page_access}
 
+
+    
     ### ----------------------------------------------------------------------------------------------------
     ### Synchronous Metadata Functions
     ### ----------------------------------------------------------------------------------------------------
@@ -964,6 +966,33 @@ class Sf:
 
 
 
+    def load_veeva_common(self):
+        self.veeva_common = self.query("Select * From Veeva_Common_vod__c").to_dict()
+        
+    def get_network_admin_sf_user_info(self):
+        sfOrgId = self.instance.split("--")[0]
+        
+        if self.veeva_common is None:
+            self.load_veeva_common()
+        
+        try:
+            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{sfOrgId}&ses={self.session_id}&oType=networkAdmin&event=getSFCredentials")
+            return response.json()
+        except:
+            return {"error": "Unable to get network admin credentials"}
+        
+    def get_network_admin_sf_user_info(self):
+        sfOrgId = self.instance.split("--")[0]
+        
+        if self.veeva_common is None:
+            self.load_veeva_common()
+        
+        try:
+            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{sfOrgId}&ses={self.session_id}&oType=networkAdmin&event=getNetworkCredentials")
+            return response.json()
+        except:
+            return {"error": "Unable to get network admin credentials"}
+
     @serialze_zeep
     def metadata_read(self, metadata_type: str, fullName: str):
         return getattr(self.sf.mdapi, metadata_type).read(fullName)
